@@ -31,8 +31,9 @@ from typing import Dict, Iterable, List, Optional, Tuple, Union
 import numpy as np
 import pandas as pd
 from component_contribution import (
-    ZENODO_DOI_PARAMETERS,
-    ZENODO_DOI_PARAMETERS_LEGACY,
+    DEFAULT_CC_PARAMS_SETTINGS,
+    LEGACY_CC_PARAMS_SETTINGS,
+    ZenodoSettings,
 )
 from component_contribution.linalg import LINALG
 from component_contribution.predict import (
@@ -40,7 +41,7 @@ from component_contribution.predict import (
     GibbsEnergyPredictor,
 )
 from equilibrator_cache import (
-    DEFAULT_ZENODO_DOI,
+    DEFAULT_COMPOUND_CACHE_SETTINGS,
     PROTON_INCHI_KEY,
     Compound,
     CompoundCache,
@@ -147,9 +148,7 @@ class ComponentContribution(object):
         self.ccache = ccache or create_compound_cache_from_zenodo()
 
         if predictor is None:
-            parameters = CCModelParameters.from_zenodo(
-                zenodo_doi=ZENODO_DOI_PARAMETERS
-            )
+            parameters = CCModelParameters.from_zenodo()
             self.predictor = GibbsEnergyPredictor(
                 parameters=parameters, rmse_inf=rmse_inf
             )
@@ -219,7 +218,7 @@ class ComponentContribution(object):
         A ComponentContribution object
         """
         cc = ComponentContribution.initialize_custom_version(
-            zenodo_doi_params=ZENODO_DOI_PARAMETERS_LEGACY
+            settings=LEGACY_CC_PARAMS_SETTINGS
         )
         cc.p_mg = Q_(14)  # i.e. set [Mg2+] to (essentially) zero
         return cc
@@ -227,10 +226,10 @@ class ComponentContribution(object):
     @staticmethod
     def initialize_custom_version(
         rmse_inf: Q_ = default_rmse_inf,
-        zenodo_doi_cache: str = DEFAULT_ZENODO_DOI,
-        zenodo_doi_params: str = ZENODO_DOI_PARAMETERS,
+        ccache_settings: ZenodoSettings = DEFAULT_COMPOUND_CACHE_SETTINGS,
+        cc_params_settings: ZenodoSettings = DEFAULT_CC_PARAMS_SETTINGS,
     ) -> "ComponentContribution":
-        """Initialize a ComponentContribution object with custom quilt versions.
+        """Initialize a ComponentContribution object with custom Zenodo versions.
 
         Parameters
         ----------
@@ -239,18 +238,16 @@ class ComponentContribution(object):
             covariance matrix for reactions outside the span of
             Component Contribution.
             (Default value: 1e-5 kJ/mol)
-        zenodo_doi_cache : str, optional
-            (Default value: "10.5281/zenodo.4128543")
-        zenodo_doi_params : str, optional
-            (Default value: "10.5281/zenodo.4013789")
+        settings : ZenodoSettings
+            The doi, filename and md5 of the
 
         Returns
         -------
         A ComponentContribution object
 
         """
-        ccache = create_compound_cache_from_zenodo(zenodo_doi_cache)
-        parameters = CCModelParameters.from_zenodo(zenodo_doi_params)
+        ccache = create_compound_cache_from_zenodo(ccache_settings)
+        parameters = CCModelParameters.from_zenodo(cc_params_settings)
         predictor = GibbsEnergyPredictor(
             parameters=parameters, rmse_inf=rmse_inf
         )
@@ -463,12 +460,15 @@ class ComponentContribution(object):
         reactions : List[PhasedReaction]
             a list of PhasedReaction objects to estimate
         uncertainty_representation : str
-            which representation to use for the uncertainties. 'cov' would
-            return a full covariance matrix. 'sqrt' would return a sqaure root
-            of the covariance, based on the uncertainty vectors.
-            'fullrank' would return a full-rank square root of the covariance
-            which is a compressed form of the 'sqrt' result.
-            (Default value: 'cov')
+            which representation to use for the uncertainties.
+            `cov` would return a full covariance matrix.
+            `precision` would return the precision matrix
+            (i.e. the inverse of the covariance matrix).
+            `sqrt` would return a sqaure root of the covariance,
+            based on the uncertainty vectors.
+            `fullrank` would return a full-rank square root of the covariance
+            which is a compressed form of the `sqrt` result.
+            (Default value: `cov`)
 
         Returns
         -------
@@ -544,12 +544,15 @@ class ComponentContribution(object):
         reactions : List[PhasedReaction]
             a list of PhasedReaction objects to estimate
         uncertainty_representation : str
-            which representation to use for the uncertainties. 'cov' would
-            return a full covariance matrix. 'sqrt' would return a sqaure root
-            of the covariance, based on the uncertainty vectors.
-            'fullrank' would return a full-rank square root of the covariance
-            which is a compressed form of the 'sqrt' result.
-            (Default value: 'cov')
+            which representation to use for the uncertainties.
+            `cov` would return a full covariance matrix.
+            `precision` would return the precision matrix
+            (i.e. the inverse of the covariance matrix).
+            `sqrt` would return a sqaure root of the covariance,
+            based on the uncertainty vectors.
+            `fullrank` would return a full-rank square root of the covariance
+            which is a compressed form of the `sqrt` result.
+            (Default value: `cov`)
         minimize_norm : bool
             if True, use an orthogonal projection to minimize the norm2 of the
             result vector (keeping it within the finite-uncertainty sub-space,
@@ -746,6 +749,7 @@ class ComponentContribution(object):
         p_h_outer: Q_,
         ionic_strength_outer: Q_,
         p_mg_outer: Q_ = default_physiological_p_mg,
+        tolerance: float = 0.0,
     ) -> ureg.Measurement:
         """Calculate the transformed energies of a multi-compartmental reaction.
 
@@ -767,6 +771,9 @@ class ComponentContribution(object):
             the ionic strength outside
         p_mg_outer : Quantity (optional)
             the pMg in the outside compartment
+        Tolerance : Float (optional)
+            tolerance for identifying inbalance between inner and outer
+            reactions (default = 0)
 
         Returns
         -------
@@ -797,11 +804,14 @@ class ComponentContribution(object):
         assert n_mg_inner == 0, "most abundant inner species have Mg2+"
         assert n_mg_outer == 0, "most abundant outer species have Mg2+"
 
-        if (n_h_inner != -n_h_outer) or (z_inner != -z_outer):
+        if (abs(n_h_inner + n_h_outer) > tolerance) or (
+            abs(z_inner + z_outer) > tolerance
+        ):
             raise ValueError(
                 "inner and outer half-reactions don't balance each other: "
                 f"n_h(inner) = {n_h_inner}, n_h(outer) = {n_h_outer}, "
                 f"z(inner) = {z_inner}, z(outer) = {z_outer}, "
+                f"tolerance = {tolerance}"
             )
 
         transported_protons = n_h_outer
